/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "MimeType.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomMimeType.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomMimeType.h"
#include "gdom/PrivateIntGdomMimeType.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::MimeType* obj)
{
    return WebCore::cacheDOMObject<WebCore::MimeType, GDOMMimeType>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMMimeType::GDOMMimeType(PassRefPtr<WebCore::MimeType> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMMimeType::~GDOMMimeType()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "MimeType.h"
#include <gdom/GdomMimeType.h>
#include <gdom/PrivateGdomMimeType.h>
#include <gdom/PrivateIntGdomMimeType.h>
#include <gdom/GdomMimeTypeprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomMimeType, gdom_mime_type, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomMimeTypePrivate {
    class WebCore::MimeType *item;
};

#define GDOM_MIME_TYPE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_MIME_TYPE, GdomMimeTypePrivate))
*/
G_END_DECLS
WebCore::MimeType *
gdom_mime_type_get_private(GdomMimeType *request)
{
    GDOMMimeType *res;
    res = static_cast<GDOMMimeType*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::MimeType*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_TYPE,
    PROP_SUFFIXES,
    PROP_DESCRIPTION,
    PROP_ENABLED_PLUGIN,
};


static void gdom_mime_type_finalize(GObject* object)
{
    /*GdomMimeType* request = GDOM_MIME_TYPE(object);*/
    /*GdomMimeTypePrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_mime_type_parent_class)->finalize(object);
}

static void gdom_mime_type__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomMimeType *self = GDOM_MIME_TYPE(object);
    WebCore::MimeType * gself = (gdom_mime_type_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_mime_type__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomMimeType *self = GDOM_MIME_TYPE(object);
    WebCore::MimeType * gself = (gdom_mime_type_get_private(self));
    switch (prop_id) {
    case PROP_TYPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->type()));
         break;
    }
    case PROP_SUFFIXES:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->suffixes()));
         break;
    }
    case PROP_DESCRIPTION:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->description()));
         break;
    }
    case PROP_ENABLED_PLUGIN:
    {
         PassRefPtr<WebCore::Plugin> ptr = gself->enabledPlugin();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_mime_type_class_init(GdomMimeTypeClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_mime_type_finalize;
    g_klass->set_property = gdom_mime_type__set_property_fn;
    g_klass->get_property = gdom_mime_type__get_property_fn;

    g_object_class_install_property (g_klass, PROP_TYPE,
            g_param_spec_string ("type", /* name */
                "mime_type_type", /* short description */
                "read-only  gchar * MimeType.type", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SUFFIXES,
            g_param_spec_string ("suffixes", /* name */
                "mime_type_suffixes", /* short description */
                "read-only  gchar * MimeType.suffixes", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_DESCRIPTION,
            g_param_spec_string ("description", /* name */
                "mime_type_description", /* short description */
                "read-only  gchar * MimeType.description", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_ENABLED_PLUGIN,
            g_param_spec_object ("enabled_plugin", /* name */
                "mime_type_enabled_plugin", /* short description */
                "read-only  GdomPlugin * MimeType.enabled_plugin", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_PLUGIN, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomMimeTypePrivate));*/
}

static void gdom_mime_type_init(GdomMimeType* request)
{
    /*GdomMimeTypePrivate* priv = GDOM_MIME_TYPE_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

